@@ -228,7 +228,7 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, flow_path_strip, replace_flow_action  # type: ignore
 
 
-__version__ = '0.3.48'
+__version__ = '0.3.49'
 
 
 FLOW_PATH_ROOT_ID = '^^^^'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -1045,7 +1045,7 @@ class LiszDataMixin:
             self.change_flow(id_of_flow('add', 'item'))
 
         elif key_code == 'e' and focused_id:
-            self.change_flow(replace_flow_action(self.flow_id, 'edit'))  # popup_kwargs=dict(parent=self.framework_win))
+            self.change_flow(replace_flow_action(self.flow_id, 'edit'))  # popup_kwargs=dict(opener=self.framework_win))
 
         elif key_code in ('-', 'del') and focused_id:
             self.change_flow(id_of_flow('confirm', 'item_deletion', focused_id))
